@@ -61,7 +61,7 @@ protected:
   virtual void finish( const Coordinate& c, const QString& s,
                        const argvect& props, bool needframe,
                        ObjectCalcer* locationparent ) = 0;
-  void leftReleased( QMouseEvent*, KigWidget*, ObjectTypeCalcer* prevlabel = 0 );
+  void leftReleased( QMouseEvent*, KigWidget*, ObjectTypeCalcer* prevlabel = nullptr );
 
 private:
   // the KigMode interface.
